@@ -109,6 +109,13 @@ class GcdTest(unittest.TestCase):
         self.assertEqual(1, gcd(-23, 15))
         self.assertEqual(12, gcd(120, 84))
         self.assertEqual(-12, gcd(84, -120))
+        self.assertEqual(652560,
+                         gcd(190738355881570558882299312308821696901058000,
+                             76478560266291874249006856460326062498333440))
+        self.assertEqual(
+            286573572687563623189610484223662247799,
+            gcd(83763289342793979220453055528167457860243376086879213707165435635135627040075,
+                33585776402955145260404154387726204875807368546078094789530226423049489520976))
 
 
 def _components(r):
@@ -359,9 +366,13 @@ class FractionTest(unittest.TestCase):
         self.assertEqual(F(27, 8), F(2, 3) ** F(-3))
         self.assertTypedEquals(2.0, F(4) ** F(1, 2))
         self.assertEqual(F(1, 1), +F(1, 1))
-        z = pow(F(-1), F(1, 2))
-        self.assertAlmostEqual(z.real, 0)
-        self.assertEqual(z.imag, 1)
+        try:
+            z = pow(F(-1), F(1, 2))
+        except ValueError:
+            self.assertEqual(2, sys.version_info[0])
+        else:
+            self.assertAlmostEqual(z.real, 0)
+            self.assertEqual(z.imag, 1)
 
     def testMixedArithmetic(self):
         self.assertTypedEquals(F(11, 10), F(1, 10) + 1)
